@@ -13,7 +13,7 @@ import plotly.graph_objs as go
 from plotly.subplots import make_subplots
 
 import plotguy
-import dash_dangerously_set_inner_html   # for all Plot Class
+#import dash_dangerously_set_inner_html   # for all Plot Class
 
 
 class Components:
